# Copyright (c) 2018 Francesco Bartoli
# 
# This software is released under the MIT License.
# https://opensource.org/licenses/MIT

# -*- coding: utf-8 -*-

"""Top-level package for marmee."""

__author__ = """Francesco Bartoli"""
__email__ = 'francesco.bartoli@geobeyond.it'
__version__ = '0.1.7'
